;; Generated package description from consult-hoogle.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "consult-hoogle" "0.7.0.0.20260720.1" "Hoogle frontend using consult" '((emacs "28.1") (consult "2.0")) :commit "42fa72c9e44e464801531d193e6edf45da6b2ee8" :authors '(("rahguzar" . "rahguzar@mailbox.org")) :maintainer '("rahguzar" . "rahguzar@mailbox.org") :keywords '("docs" "languages") :url "https://codeberg.org/rahguzar/consult-hoogle")
